"use strict";
var chalk = require('chalk');
var LOG_LEVELS = {
    error: {
        color: 'red'
    },
    warn: {
        color: 'yellow'
    },
    info: {
        color: 'cyan'
    },
    debug: {
        color: 'white'
    }
};
var log = function (message, severity) {
    if (severity === void 0) { severity = 'info'; }
    var color = LOG_LEVELS[severity].color || 'cyan';
    console.log(chalk[color](message));
};
var presets = {
    angular: {
        validate: function (message) {
            var MAX_LENGTH = 100;
            var PATTERN = /^(?:fixup!\s*)?(\w*)(\(([\w\$\.\*/-]*)\))?\: (.*)$/;
            var TYPES = {
                feat: true,
                fix: true,
                docs: true,
                style: true,
                refactor: true,
                perf: true,
                test: true,
                chore: true,
                revert: true
            };
            if (message.length >= MAX_LENGTH) {
                log("Message is longer than " + MAX_LENGTH + " characters!", 'error');
                return false;
            }
            var match = PATTERN.exec(message);
            if (!match) {
                log("Message does not match \"<type>(<scope>): <subject>\"! was: " + message, 'error');
                return false;
            }
            var type = match[1];
            if (!TYPES.hasOwnProperty(type)) {
                log("'" + type + "' is not an allowed type!", 'error');
                log("Valid types are: " + Object.keys(TYPES).join(', '), 'info');
                return false;
            }
            return true;
        },
        ignorePattern: /^WIP\:/
    },
    atom: {
        validate: function (message) {
            var MAX_LENGTH = 72;
            var EMOJIS = [
                ':art:',
                ':racehorse:',
                ':non-potable_water:',
                ':memo:',
                ':penguin:',
                ':apple:',
                ':checkered_flag:',
                ':bug:',
                ':fire:',
                ':green_heart:',
                ':white_check_mark:',
                ':lock:',
                ':arrow_up:',
                ':arrow_down:',
                ':shirt:'
            ];
            var PATTERN = new RegExp("^(" + EMOJIS.join('|') + ")(?: )(?:.*)$");
            if (message.length > MAX_LENGTH) {
                log("Message is longer than " + MAX_LENGTH + " characters!", 'error');
                return false;
            }
            var match = PATTERN.exec(message);
            if (!match) {
                log("Message does not match \"<emoji> <subject>\"! was: " + message, 'error');
                log("Valid emojis are: " + EMOJIS.join(', '), 'info');
                return false;
            }
            return true;
        }
    },
    eslint: {
        validate: function (message) {
            var FIXUP = '(?:fixup!\\s*)?';
            var TAG = '([A-Z][a-z]+)';
            var GH = '(?:(?:[A-Za-z0-9_-]+)\\/(?:[A-Za-z0-9_.-]+))?(?:(?:#|[Gg][Hh]-)\\d+)';
            var MESSAGE = "((?=[A-Z0-9])(?:(?!" + GH + ").)*)";
            var ISSUE = "(\\s\\((?:(?:(?:fixes|refs)\\s" + GH + ")(?:,\\s(?!\\))|\\)))+)?";
            var PATTERN = new RegExp("^" + FIXUP + TAG + ":\\s" + MESSAGE + ISSUE + "$");
            var match = PATTERN.exec(message);
            if (!match) {
                log('Message does not match "Tag: Message (fixes #1234)".', 'error');
                log("Given: \"" + message + "\".", 'info');
                return false;
            }
            var matches = match.filter(function (str) { return str ? true : false; }).map(function (str) { return str.trim(); });
            var TAGS = ['Fix', 'Update', 'Breaking', 'Docs', 'Build', 'New', 'Upgrade'];
            if (TAGS.indexOf(matches[1]) === -1) {
                log("The word \"" + matches[1] + "\" is not an allowed tag.", 'error');
                log("Valid types are: " + TAGS.join(', ') + ".", 'info');
                return false;
            }
            return true;
        },
        ignorePattern: /^WIP\:/
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = presets;
